@@ -29,7 +29,7 @@ import glob
 import logging
 import os
 import shutil
-from typing import Any, Callable, List
+from typing import Any, Callable, Generator, List, Tuple
 
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
@@ -158,3 +158,40 @@ def preserve_cwd(func: Callable) -> Callable:
         os.chdir(cwd)
         return result
     return decorator
+
+
+def gen_filenames(starting_filenames: List[str],
+                  recursive: bool) -> Generator[str, None, None]:
+    for base_filename in starting_filenames:
+        if os.path.isfile(base_filename):
+            yield os.path.abspath(base_filename)
+        elif os.path.isdir(base_filename) and recursive:
+            for dirpath, dirnames, filenames in os.walk(base_filename):
+                for fname in filenames:
+                    yield os.path.abspath(os.path.join(dirpath, fname))
+
+
+def exists_locked(filepath: str) -> Tuple[bool, bool]:
+    """
+    Checks if a file is locked by opening it in append mode.
+    If no exception thrown, then the file is not locked.
+    # https://www.calazan.com/how-to-check-if-a-file-is-locked-in-python/
+    """
+    exists = False
+    locked = None
+    file_object = None
+    if os.path.exists(filepath):
+        exists = True
+        locked = True
+        try:
+            buffer_size = 8
+            # Opening file in append mode and read the first 8 characters.
+            file_object = open(filepath, 'a', buffer_size)
+            if file_object:
+                locked = False  # exists and not locked
+        except IOError:
+            pass
+        finally:
+            if file_object:
+                file_object.close()
+    return exists, locked
