@@ -21,7 +21,7 @@
 ===============================================================================
 """
 
-VERSION = '1.0.5'
+VERSION = '1.0.6'
 # Use semantic versioning: http://semver.org/
 
 RECENT_VERSION_HISTORY = """
@@ -59,10 +59,7 @@ First started in 2009.
 - 1.0.3, 2017-10-18.
   Several small changes for CamCOPS.
   
-- 1.0.4, 2017-10-20.
-  Similarly.
-
-- 1.0.5, 2017-10-22.
+- ... to 1.0.6, 2017-10-22.
   Similarly.
 
 """
